Changelog
=========


(unreleased)
------------
- During tests, path_schemas to point to tmp folder. [sdementen]
- Use setup.cfg instead of .flake8. [sdementen]
- Add blank in some gnucash book name for testing purposes. [sdementen]
- Mypy fixes. [sdementen]
- Add make CLI implemented in python. [sdementen]
- Fix flake8 issues. [sdementen]
- Fix linter issues. [sdementen]
- Adapt linter to use 140 charts per line. [sdementen]
- Remove the rename_project.yml CI action. [sdementen]
- Add sqlacodegen_v2 as dependency. [sdementen]
- Update setup.py with maturity and description. [sdementen]
- Add some simple tests. [sdementen]
- Add example in README.md. [sdementen]
- Add first working code. [sdementen]
- Add data folder with sample of gnucash sqlite books. [sdementen]
- Release: version 0.1.1 🚀 [sdementen]


0.1.1 (2024-06-24)
------------------
- Release: version 0.1.1 🚀 [Sébastien de Menten]
- Clean up repo generated from template. [Sébastien de Menten]
- ✅ Ready to clone and code. [sdementen]
- Initial commit. [sdementen]


